==> nextcloud-18.0.4.tgz: nextcloud/apps/notifications/l10n/sv.js <==
OC.L10N.register(
    "notifications",
    {
    "Admin notifications" : "Administratörsaviseringar",
    "Notifications" : "Aviseringar",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Denna app ger en backend och frontend för aviserings-API:n tillgänglig i Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin",
    "Dismiss all notifications" : "Avfärda alla aviseringar",
    "No notifications" : "Inga aviseringar",
    "Failed to dismiss all notifications" : "Misslyckades att avfärda alla aviseringar",
    "Failed to perform action" : "Misslyckades utföra åtgärd",
    "Dismiss" : "Avfärda",
    "Failed to dismiss notification" : "Misslyckades att avfärda notifiering",
    "in {path}" : "i {path}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.6.tgz: nextcloud/apps/notifications/l10n/sv.js <==
OC.L10N.register(
    "notifications",
    {
    "Admin notifications" : "Administratörsaviseringar",
    "Notifications" : "Aviseringar",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Denna app ger en backend och frontend för aviserings-API:n tillgänglig i Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin",
    "Dismiss all notifications" : "Avfärda alla aviseringar",
    "Requesting browser permissions to show notifications" : "Begär webbläsartillstånd för att visa aviseringar",
    "No notifications" : "Inga aviseringar",
    "Failed to dismiss all notifications" : "Misslyckades att avfärda alla aviseringar",
    "Failed to perform action" : "Misslyckades utföra åtgärd",
    "Dismiss" : "Avfärda",
    "Failed to dismiss notification" : "Misslyckades att avfärda notifiering",
    "in {path}" : "i {path}"
},
"nplurals=2; plural=(n != 1);");
